@@ -5,7 +5,7 @@ use warnings;
 
 use 5.008;
 
-our $VERSION = '0.33';
+our $VERSION = '0.36';
 
 1;
 
@@ -23,7 +23,7 @@ Specio - Type constraints and coercions for Perl
 
 =head1 VERSION
 
-version 0.33
+version 0.36
 
 =head1 SYNOPSIS
 
@@ -176,11 +176,12 @@ check unless it I<also> overloads boolification.
 Most types do not check that the overloaded method actually returns something
 that matches the constraint. This may change in the future.
 
-The C<Bool> type accepts an object that provides C<bool> overloading.
+The C<Bool> type accepts an object that implements C<bool> overloading.
 
-The C<Str> type accepts an object that provides string (C<q{""}>) overloading.
+The C<Str> type accepts an object that implements string (C<q{""}>)
+overloading.
 
-The C<Num> type accepts an object that provides numeric C<'0+'}>
+The C<Num> type accepts an object that implements numeric (C<'0+'}>)
 overloading. The C<Int> type does as well, but it will check that the
 overloading returns an actual integer.
 
@@ -440,12 +441,22 @@ button at L<http://www.urth.org/~autarch/fs-donation.html>.
 
 Dave Rolsky <autarch@urth.org>
 
-=head1 CONTRIBUTOR
+=head1 CONTRIBUTORS
 
-=for stopwords Karen Etheridge
+=for stopwords Graham Knop Karen Etheridge
+
+=over 4
+
+=item *
+
+Graham Knop <haarg@haarg.org>
+
+=item *
 
 Karen Etheridge <ether@cpan.org>
 
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is Copyright (c) 2012 - 2017 by Dave Rolsky.
